@@ -18,14 +18,14 @@
 # along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
 test.NumericMatrix <- function(){
-	funx <- cfunction(signature(x = "matrix" ), '
+	funx <- cppfunction(signature(x = "matrix" ), '
 		NumericMatrix m(x) ;
 		double trace = 0.0 ;
 		for( size_t i=0 ; i<4; i++){
 			trace += m(i,i) ;
 		}
 		return wrap( trace ) ;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;"  )
+	'  )
 	x <- matrix( 1:16 + .5, ncol = 4 )
 	checkEquals( funx(x), sum(diag(x)), msg = "matrix indexing" )
 
@@ -35,27 +35,27 @@ test.NumericMatrix <- function(){
 }
 
 test.CharacterMatrix <- function(){
-	funx <- cfunction(signature(x = "matrix" ), '
+	funx <- cppfunction(signature(x = "matrix" ), '
 		CharacterMatrix m(x) ;
 		std::string trace ;
 		for( size_t i=0 ; i<4; i++){
 			trace += m(i,i) ;
 		}
 		return wrap( trace ) ;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;"  )
+	'  )
 	x <- matrix( letters[1:16], ncol = 4 )
 	checkEquals( funx(x), paste( diag(x), collapse = "" ) )
 }
 
 test.GenericMatrix <- function( ){
-	funx <- cfunction(signature(x = "matrix" ), '
+	funx <- cppfunction(signature(x = "matrix" ), '
 		GenericMatrix m(x) ;
 		List output( m.ncol() ) ;
 		for( size_t i=0 ; i<4; i++){
 			output[i] = m(i,i) ;
 		}
 		return output ;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;"  )
+	'  )
 	g <- function(y){
 		sapply( y, function(x) seq(from=x, to = 16) )
 	}
@@ -64,37 +64,31 @@ test.GenericMatrix <- function( ){
 }
 
 test.IntegerMatrix.diag <- function(){
-	fx <- cfunction( signature(), '
-		return IntegerMatrix::diag( 5, 1 ) ;
-	',
-	Rcpp  = TRUE, includes = "using namespace Rcpp;" )
+	fx <- cppfunction( signature(), 'return IntegerMatrix::diag( 5, 1 ) ; '  )
 	expected <- matrix( 0L, nrow = 5, ncol = 5 )
 	diag( expected ) <- 1L
 	checkEquals( fx(), expected, msg = "IntegerMatrix::diag" )
 }
 
 test.CharacterMatrix.diag <- function(){
-	fx <- cfunction( signature(), '
-		return CharacterMatrix::diag( 5, "foo" ) ;
-	',
-	Rcpp  = TRUE, includes = "using namespace Rcpp;" )
+	fx <- cppfunction( signature(), 'return CharacterMatrix::diag( 5, "foo" ) ;' )
 	expected <- matrix( "", nrow = 5, ncol = 5 )
 	diag( expected ) <- "foo"
 	checkEquals( fx(), expected, msg = "CharacterMatrix::diag" )
 }
 
 test.NumericMatrix.Ctors <- function(){
-	funx <- cfunction(signature(), '
+	funx <- cppfunction(signature(), '
 		NumericMatrix m(3);
 		return m;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;"  )
+	'  )
 	x <- matrix(0, 3, 3)
 	checkEquals( funx(), x, msg = "matrix from single int" )
 
-	funx <- cfunction(signature(), '
+	funx <- cppfunction(signature(), '
 		NumericMatrix m(3,3);
 		return m;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;"  )
+	'  )
 	x <- matrix(0, 3, 3)
 	checkEquals( funx(), x, msg = "matrix from two int" )
 }
