@@ -17,12 +17,8 @@
 # You should have received a copy of the GNU General Public License
 # along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
-.setUp <- function(){
-	suppressMessages( require( inline ) )
-}
-
 test.RObject.S4methods <- function(){
-	funx <- cfunction(signature(x = "ANY" ), '
+	funx <- cppfunction(signature(x = "ANY" ), '
 	RObject y(x) ;
 	List res(5) ;
 	res[0] = y.isS4() ;
@@ -31,7 +27,7 @@ test.RObject.S4methods <- function(){
 	res[3] = y.slot("x") ;
 	res[4] = y.slot("y") ;
 	return res ;
-	', Rcpp=TRUE, verbose=FALSE, includes = "using namespace Rcpp;" )
+	' )
 	setClass("track",
            representation(x="numeric", y="numeric"))
 	tr <- new( "track", x = 2, y = 2 )
@@ -39,28 +35,28 @@ test.RObject.S4methods <- function(){
 		list( TRUE, TRUE, FALSE, 2.0, 2.0 )
 	, msg = "slot management" )
 	
-	funx <- cfunction(signature(x = "ANY" ), '
+	funx <- cppfunction(signature(x = "ANY" ), '
 	RObject y(x) ;
 	y.slot( "x" ) = 10.0 ;
 	y.slot( "y" ) = 20.0 ;
 	return R_NilValue ;
-	', Rcpp=TRUE, verbose=FALSE, includes = "using namespace Rcpp;" )
+	' )
 	funx( tr )
 	checkEquals( tr@x, 10.0 , msg = "slot('x') = 10" )
 	checkEquals( tr@y, 20.0 , msg = "slot('y') = 20" )
 	
-	funx <- cfunction(signature(x = "ANY" ), '
+	funx <- cppfunction(signature(x = "ANY" ), '
 	RObject y(x) ;
 	y.slot( "foo" ) = 10.0 ;
 	return R_NilValue ;
-	', Rcpp=TRUE, verbose=FALSE, includes = "using namespace Rcpp;" )
+	' )
 	checkException( funx( tr ), msg = "slot does not exist" )
 	
-	funx <- cfunction(signature(x = "ANY" ), '
+	funx <- cppfunction(signature(x = "ANY" ), '
 	RObject y(x) ;
 	y.slot( "foo" ) ;
 	return R_NilValue ;
-	', Rcpp=TRUE, verbose=FALSE, includes = "using namespace Rcpp;" )
+	' )
 	checkException( funx( tr ), msg = "slot does not exist" )
 	
 }
@@ -70,19 +66,18 @@ test.S4 <- function(){
 	setClass("track",
            representation(x="numeric", y="numeric"))
 	tr <- new( "track", x = 2, y = 3 )
-	fx <- cfunction( signature( x = "ANY" ),
-                        'S4 o(x); return o.slot( "x" ) ;', 
-		Rcpp = TRUE, includes = "using namespace Rcpp;" )
+	fx <- cppfunction( signature( x = "ANY" ),
+                        'S4 o(x); return o.slot( "x" ) ;')
 	checkEquals( fx( tr ), 2, msg = "S4( SEXP )" )
 	
 	checkException( fx( list( x = 2, y = 3 ) ), msg = "not S4" )
 	checkException( fx( structure( list( x = 2, y = 3 ), class = "track" ) ), msg = "S3 is not S4" )
 
-	fx <- cfunction( signature( clazz = "character" ), 
+	fx <- cppfunction( signature( clazz = "character" ), 
 		'
 		std::string cl = as<std::string>( clazz );
 		return S4( cl ); 
-		', Rcpp = TRUE, includes = "using namespace Rcpp ;" )
+		' )
 	tr <- fx( "track" )
 	checkTrue( inherits( tr, "track" ) )
 	checkEquals( tr@x, numeric(0) )
@@ -91,3 +86,50 @@ test.S4 <- function(){
 	
 }
 
+
+test.S4.is <- function(){
+	setClass("track", representation(x="numeric", y="numeric"))
+	setClass("trackCurve", representation(smooth = "numeric"), contains = "track")
+	
+	tr1 <- new( "track", x = 2, y = 3 )
+	tr2 <- new( "trackCurve", x = 2, y = 3, smooth = 5 )
+	
+	fx <- cppfunction( signature(tr="ANY"), '
+		S4 o(tr) ;
+		return wrap( o.is( "track" ) ) ;
+		' )
+	checkTrue( fx( tr1 ), msg = 'track is track' )
+	checkTrue( fx( tr2 ), msg = 'trackCurve is track' )
+	
+	fx <- cppfunction( signature(tr="ANY"), '
+		S4 o(tr) ;
+		return wrap( o.is( "trackCurve" ) ) ;
+		' )
+	checkTrue( !fx( tr1 ), msg = 'track is not trackCurve' )
+	checkTrue( fx( tr2 ), msg = 'trackCurve is trackCurve' )
+	
+}
+
+test.Vector.SlotProxy.ambiguity <- function(){
+	setClass("track", representation(x="numeric", y="numeric"))
+	setClass("trackCurve", representation(smooth = "numeric"), contains = "track")
+	
+	tr1 <- new( "track", x = 2, y = 3 )
+	fx <- cppfunction( signature(tr="ANY"), 
+		' S4 o(tr); return NumericVector(o.slot("x")); '
+	)
+	checkEquals( fx(tr1), 2, "Vector( SlotProxy ) ambiguity" )
+	
+}
+
+test.Vector.AttributeProxy.ambiguity <- function(){
+	x <- 1:10
+	attr( x, "foo" ) <- "bar"
+	
+	fx <- cppfunction( signature(tr="ANY"), 
+		' IntegerVector o(tr); return CharacterVector(o.attr("foo")); '
+	)
+	checkEquals( fx(x), "bar", "Vector( AttributeProxy ) ambiguity" )
+	
+}
+
