@@ -17,21 +17,17 @@
 # You should have received a copy of the GNU General Public License
 # along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
-.setUp <- function(){
-	require( inline )
-}
-
 test.clone <- function(){
 	
 	x <- 1:10
-	funx <- cfunction(signature(x="integer"), '
+	funx <- cppfunction(signature(x="integer"), '
 	IntegerVector vec(x) ;
 	IntegerVector dolly = clone( vec ) ;
 	for( size_t i=0; i<10; i++){
 		dolly[i] = 10 - i ;
 	}
 	return dolly ;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;" )
+	' )
 	y <- funx(x)
 	checkEquals( x, 1:10, msg = "clone" )
 	checkEquals( y, 10:1, msg = "clone" )
